util

package
v0.0.0-...-738b618 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 13, 2023 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Escape

func Escape(s string) (r string)

func IncludeInEnvvar

func IncludeInEnvvar(envvar, valueadd string) bool

includeInEnvvar is a function that modifies a given envvar to contain the given element if it doesn't already have it. Returns true if it modified the envvar and false if the envvar already contained the element.

func RestoreEnvvars

func RestoreEnvvars(envvarsave *map[string]string, envvars ...string)

func SaveEnvvars

func SaveEnvvars(envvarsave *map[string]string, envvars ...string)

func Unescape

func Unescape(s string) (r string)

Types

This section is empty.

Jump to