Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func IncludeInEnvvar ¶
includeInEnvvar is a function that modifies a given envvar to contain the given element if it doesn't already have it. Returns true if it modified the envvar and false if the envvar already contained the element.
func RestoreEnvvars ¶
func SaveEnvvars ¶
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.